Class: OpenTelemetry::Instrumentation::Grape::Instrumentation

Inherits:
Base
  • Object
show all
Defined in:
lib/opentelemetry/instrumentation/grape/instrumentation.rb

Overview

The Instrumentation class contains logic to detect and install the Grape instrumentation

Configuration keys and options

:ignored_events

Default is []. Specifies which ActiveSupport::Notifications events published by Grape to ignore. Ignored events will not be published as Span events.

:install_rack

Default is true. Specifies whether or not to install the Rack instrumentation as part of installing the Grape instrumentation. This is useful in cases where you have multiple Rack applications but want to manually specify where to insert the tracing middleware.

Constant Summary collapse

MINIMUM_VERSION =

Minimum Grape version needed for compatibility with this instrumentation

Gem::Version.new('1.2.0')